API
===

.. autofunction:: zoomies.KinematicAgeSpline.fit_mono_spline
.. autofunction:: zoomies.KinematicAgeSpline.write
.. autofunction:: zoomies.KinematicAgeSpline.evaluate_spline
.. autofunction:: zoomies.KinematicAgeSpline.plot_fit
.. autofunction:: zoomies.KinematicAgeSpline.evaluate_ages

.. autofunction:: zoomies.calc_jz
